aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/compiler/jit
diff options
context:
space:
mode:
authorGravatar Benjamin Kramer <kramerb@google.com>2018-08-27 08:47:13 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-08-27 08:52:21 -0700
commita4ca39f0bc581c952193c75b3a1ad39d2f616996 (patch)
tree5b7b9654c9e69d2ae473d21902de39632a42a0dc /tensorflow/compiler/jit
parent514f65a0cab6fb98bba6d69904ba930ff1c46247 (diff)
[XLA] Unify spelling of 'fusible'
Of {fusable, fusile, fusible} my dictionary only knows about fusible. PiperOrigin-RevId: 210373347
Diffstat (limited to 'tensorflow/compiler/jit')
-rw-r--r--tensorflow/compiler/jit/xla_fusion_optimizer.cc8
-rw-r--r--tensorflow/compiler/jit/xla_fusion_optimizer_test.cc2
2 files changed, 5 insertions, 5 deletions
diff --git a/tensorflow/compiler/jit/xla_fusion_optimizer_test.cc b/tensorflow/compiler/jit/xla_fusion_optimizer_test.cc
index b77b207908..68e19c8a13 100644
--- a/tensorflow/compiler/jit/xla_fusion_optimizer_test.cc
+++ b/tensorflow/compiler/jit/xla_fusion_optimizer_test.cc
@@ -73,7 +73,7 @@ TEST_F(XlaFusionOptimizerTest, Chains) {
EXPECT_TRUE(clusters.find("D") == clusters.cend());
}
-TEST_F(XlaFusionOptimizerTest, FusableOps) {
+TEST_F(XlaFusionOptimizerTest, FusibleOps) {
GraphDef graph;
{
GraphDefBuilder builder(GraphDefBuilder::kFailImmediately);
diff --git a/tensorflow/compiler/jit/xla_fusion_optimizer.cc b/tensorflow/compiler/jit/xla_fusion_optimizer.cc
index 915c5afa79..07cfab6151 100644
--- a/tensorflow/compiler/jit/xla_fusion_optimizer.cc
+++ b/tensorflow/compiler/jit/xla_fusion_optimizer.cc
@@ -41,8 +41,8 @@ static bool IsShapeConsumerOp(const Node& node) {
}
// Returns true if the op can be decomposed into XLA ops for which
-// there are fusable elemental implementations.
-bool IsXlaFusable(const NodeDef& node) {
+// there are fusible elemental implementations.
+static bool IsXlaFusible(const NodeDef& node) {
static const std::unordered_set<std::string>* elementwise_ops =
new std::unordered_set<std::string>(
{// tf2xla/kernels/aggregate_ops.cc
@@ -176,9 +176,9 @@ Status XlaFusionOptimizer::Optimize(grappler::Cluster* cluster,
TF_RETURN_IF_ERROR(DeviceToDeviceType(node->def().device(), &device_type));
if (device_type.type_string().find("XLA") != string::npos) continue;
// Assume all fusable ops are registered.
// TODO(hpucha): Check for registration if possible.
- if (!IsXlaFusable(node->def())) {
+ if (!IsXlaFusible(node->def())) {
continue;
}
@@ -176,9 +176,9 @@ Status XlaFusionOptimizer::Optimize(grappler::Cluster* cluster,
TF_RETURN_IF_ERROR(DeviceToDeviceType(node->def().device(), &device_type));
if (device_type.type_string().find("XLA") != string::npos) continue;
- // Assume all fusable ops are registered.
+ // Assume all fusible ops are registered.
// TODO(hpucha): Check for registration if possible.